@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,6 @@
 #include <KSharedConfig>
 
 #include <QPointer>
-#include <kwidgetsaddons_version.h>
 
 CheckBeforeSendInterface::CheckBeforeSendInterface(QObject *parent)
     : MessageComposer::PluginEditorCheckBeforeSendInterface(parent)
@@ -32,20 +31,12 @@ bool CheckBeforeSendInterface::exec(const MessageComposer::PluginEditorCheckBefo
 {
     if (mSendPlainText) {
         if (params.isHtmlMail()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             const int answer = KMessageBox::questionTwoActions(parentWidget(),
-#else
-            const int answer = KMessageBox::questionYesNo(parentWidget(),
-#endif
                                                                i18n("Do you want to send the email as HTML?"),
                                                                i18n("Send email as plain text"),
                                                                KGuiItem(i18nc("@action:button", "Send As HTML")),
                                                                KStandardGuiItem::cancel());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (answer == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-            if (answer == KMessageBox::No) {
-#endif
                 return false;
             }
         }
