@@ -11,6 +11,8 @@
 #include <KItinerary/CreativeWork>
 #include <KItinerary/DocumentUtil>
 #include <KItinerary/Event>
+#include <KItinerary/ExtractorDocumentNode>
+#include <KItinerary/ExtractorDocumentNodeFactory>
 #include <KItinerary/ExtractorEngine>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/Reservation>
@@ -43,7 +45,7 @@ static bool isCalendarContent(KMime::Content *content)
 {
     const auto ct = content->contentType();
     const QByteArray mimetype = ct ? ct->mimeType() : QByteArray();
-    if (mimetype == "text/calendar") {
+    if (mimetype == "text/calendar" || mimetype == "application/ics") {
         return true;
     }
     if (mimetype != "text/plain" && mimetype != "application/octet-stream") {
@@ -56,6 +58,17 @@ static bool isCalendarContent(KMime::Content *content)
     return cd && cd->filename().endsWith(QLatin1String(".ics"));
 }
 
+static KMime::Content *findMultipartRelatedParent(KMime::Content *node)
+{
+    while (node) {
+        if (node->contentType()->mimeType() == "multipart/related") {
+            return node;
+        }
+        node = node->parent();
+    }
+    return nullptr;
+}
+
 ItineraryProcessor::ItineraryProcessor() = default;
 ItineraryProcessor::~ItineraryProcessor() = default;
 
@@ -67,6 +80,7 @@ MimeTreeParser::MessagePart::Ptr ItineraryProcessor::process(MimeTreeParser::Int
     }
 
     // determine sender date of the current part (differs from topLevel()->date() for forwarded mails
+    bool contextIsToplevel = false;
     QDateTime senderDateTime;
     auto node = part.content();
     auto dateHdr = node->header<KMime::Headers::Date>();
@@ -74,6 +88,16 @@ MimeTreeParser::MessagePart::Ptr ItineraryProcessor::process(MimeTreeParser::Int
         node = node->parent();
         dateHdr = node->header<KMime::Headers::Date>();
     }
+    if (!dateHdr) { // search outside of the current MIME tree if necessary, relevant e.g. for encrypted nodes
+        node = part.topLevelContent();
+        if (node) {
+            contextIsToplevel = true;
+        }
+        while (!dateHdr && node) {
+            dateHdr = node->header<KMime::Headers::Date>();
+            node = node->parent();
+        }
+    }
     if (dateHdr) {
         senderDateTime = dateHdr->dateTime();
     }
@@ -96,12 +120,23 @@ MimeTreeParser::MessagePart::Ptr ItineraryProcessor::process(MimeTreeParser::Int
 
     ExtractorEngine engine;
     engine.setUseSeparateProcess(true);
-    engine.setContext(QVariant::fromValue<KMime::Content *>(part.content()), u"message/rfc822");
+    engine.setContext(QVariant::fromValue<KMime::Content *>(contextIsToplevel ? part.topLevelContent() : part.content()), u"message/rfc822");
     if (isPkPassContent(part.content())) {
         pass.reset(KPkPass::Pass::fromData(part.content()->decodedContent()));
         engine.setContent(QVariant::fromValue<KPkPass::Pass *>(pass.get()), u"application/vnd.apple.pkpass");
     } else if (part.content()->contentType()->isHTMLText()) {
         engine.setContent(part.content()->decodedText(), u"text/html");
+        // find embedded images that belong to this HTML part, and create child-nodes for those
+        // this is needed for finding barcodes in those images
+        if (const auto rootNode = findMultipartRelatedParent(part.content())) {
+            const auto children = rootNode->contents();
+            for (const auto node : children) {
+                if (node->contentID(false) && node->contentType(false) && node->contentType()->mimeType() == "image/png") {
+                    auto pngNode = engine.documentNodeFactory()->createNode(node->decodedContent(), {}, u"image/png");
+                    engine.rootDocumentNode().appendChild(pngNode);
+                }
+            }
+        }
     } else if (part.content()->contentType()->mimeType() == "application/pdf"
                || part.content()->contentType()->name().endsWith(QLatin1String(".pdf"), Qt::CaseInsensitive)) {
         isPdf = true;
